# pyttop
Python Tools for Table Operations and Plotting (PyTTOP) is a Python package.

See the [documentation](https://pyttop.readthedocs.io/) for details.

This package is distributed *solely* under the [GNU General Public License v3.0](https://www.gnu.org/licenses/gpl-3.0.html) (GPL-3.0). 

## Installation

To install this package, run the following command: 
```
pip install pyttop
```
If you would like to try the latest development version, you may directly install from the project repository by:
```
pip install git+https://github.com/ycwang-astro/pyttop.git
```
